windows_osk_guard library

Classes

GlobalTouchKeyboardGuard
A global widget that intercept touch events and controls the Windows virtual keyboard.
GlobalTouchKeyboardGuardState
KeyboardSuppressingNavigatorObserver
Suppresses the Windows touch keyboard during Navigator page transitions.
OskWindowMonitor
Real-time monitor for the Windows touch keyboard window visibility.
TouchBridge
A FFI bridge that binds to the native Windows C++ DLL to control the virtual keyboard.
WindowsOskGuard
Stub class to satisfy default Flutter project template files and tests.

Typedefs

GetLastInputWasTouchDart = bool Function()
GetLastInputWasTouchNative = Bool Function()
SetTouchKeyboardVisibleDart = void Function(bool visible)
SetTouchKeyboardVisibleNative = Void Function(Bool visible)
SetTouchToMouseEnabledDart = void Function(bool enabled)
SetTouchToMouseEnabledNative = Void Function(Bool enabled)